# PulpPythonClient::DistributionsPypiApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](DistributionsPypiApi.md#create) | **POST** /pulp/api/v3/distributions/python/pypi/ | Create a python distribution
[**delete**](DistributionsPypiApi.md#delete) | **DELETE** {python_python_distribution_href} | Delete a python distribution
[**list**](DistributionsPypiApi.md#list) | **GET** /pulp/api/v3/distributions/python/pypi/ | List python distributions
[**partial_update**](DistributionsPypiApi.md#partial_update) | **PATCH** {python_python_distribution_href} | Update a python distribution
[**read**](DistributionsPypiApi.md#read) | **GET** {python_python_distribution_href} | Inspect a python distribution
[**update**](DistributionsPypiApi.md#update) | **PUT** {python_python_distribution_href} | Update a python distribution



## create

> AsyncOperationResponse create(python_python_distribution)

Create a python distribution

Trigger an asynchronous create task

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::DistributionsPypiApi.new
python_python_distribution = PulpPythonClient::PythonPythonDistribution.new # PythonPythonDistribution | 

begin
  #Create a python distribution
  result = api_instance.create(python_python_distribution)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling DistributionsPypiApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_distribution** | [**PythonPythonDistribution**](PythonPythonDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## delete

> AsyncOperationResponse delete(python_python_distribution_href)

Delete a python distribution

Trigger an asynchronous delete task

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::DistributionsPypiApi.new
python_python_distribution_href = 'python_python_distribution_href_example' # String | 

begin
  #Delete a python distribution
  result = api_instance.delete(python_python_distribution_href)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling DistributionsPypiApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_distribution_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedpythonPythonDistributionResponseList list(opts)

List python distributions

 Pulp Python Distributions are used to distribute Python content from Python Repositories or Python Publications.  Pulp Python Distributions should not be confused with \"Python Distribution\" as defined by the Python community. In Pulp usage, Python content is referred to as Python Package Content.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::DistributionsPypiApi.new
opts = {
  base_path: 'base_path_example', # String | 
  base_path__contains: 'base_path__contains_example', # String | Filter results where base_path contains value
  base_path__icontains: 'base_path__icontains_example', # String | Filter results where base_path contains value
  base_path__in: ['base_path__in_example'], # Array<String> | Filter results where base_path is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  name: 'name_example', # String | 
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  pulp_label_select: 'pulp_label_select_example', # String | Filter labels by search string
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List python distributions
  result = api_instance.list(opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling DistributionsPypiApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **base_path** | **String**|  | [optional] 
 **base_path__contains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__icontains** | **String**| Filter results where base_path contains value | [optional] 
 **base_path__in** | [**Array&lt;String&gt;**](String.md)| Filter results where base_path is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **name** | **String**|  | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **pulp_label_select** | **String**| Filter labels by search string | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedpythonPythonDistributionResponseList**](PaginatedpythonPythonDistributionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AsyncOperationResponse partial_update(python_python_distribution_href, patchedpython_python_distribution)

Update a python distribution

Trigger an asynchronous partial update task

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::DistributionsPypiApi.new
python_python_distribution_href = 'python_python_distribution_href_example' # String | 
patchedpython_python_distribution = PulpPythonClient::PatchedpythonPythonDistribution.new # PatchedpythonPythonDistribution | 

begin
  #Update a python distribution
  result = api_instance.partial_update(python_python_distribution_href, patchedpython_python_distribution)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling DistributionsPypiApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_distribution_href** | **String**|  | 
 **patchedpython_python_distribution** | [**PatchedpythonPythonDistribution**](PatchedpythonPythonDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> PythonPythonDistributionResponse read(python_python_distribution_href, opts)

Inspect a python distribution

 Pulp Python Distributions are used to distribute Python content from Python Repositories or Python Publications.  Pulp Python Distributions should not be confused with \"Python Distribution\" as defined by the Python community. In Pulp usage, Python content is referred to as Python Package Content.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::DistributionsPypiApi.new
python_python_distribution_href = 'python_python_distribution_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect a python distribution
  result = api_instance.read(python_python_distribution_href, opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling DistributionsPypiApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_distribution_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**PythonPythonDistributionResponse**](PythonPythonDistributionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AsyncOperationResponse update(python_python_distribution_href, python_python_distribution)

Update a python distribution

Trigger an asynchronous update task

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::DistributionsPypiApi.new
python_python_distribution_href = 'python_python_distribution_href_example' # String | 
python_python_distribution = PulpPythonClient::PythonPythonDistribution.new # PythonPythonDistribution | 

begin
  #Update a python distribution
  result = api_instance.update(python_python_distribution_href, python_python_distribution)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling DistributionsPypiApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **python_python_distribution_href** | **String**|  | 
 **python_python_distribution** | [**PythonPythonDistribution**](PythonPythonDistribution.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

