# PulpPythonClient::PypiSimpleApi

All URIs are relative to *https://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](PypiSimpleApi.md#create) | **POST** /pypi/{path}/simple/ | Upload a package
[**read**](PypiSimpleApi.md#read) | **GET** /pypi/{path}/simple/ | Get index simple page
[**read_0**](PypiSimpleApi.md#read_0) | **GET** /pypi/{path}/simple/{package}/ | Get package simple page



## create

> PackageUploadTaskResponse create(path, content, sha256_digest, opts)

Upload a package

Upload package to the index. This endpoint has the same functionality as the upload endpoint at the `/legacy` url of the index. This is provided for convenience for users who want a single index url for all their Python tools. (pip, twine, poetry, pipenv, ...)

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::PypiSimpleApi.new
path = 'path_example' # String | 
content = File.new('/path/to/file') # File | A Python package release file to upload to the index.
sha256_digest = 'sha256_digest_example' # String | SHA256 of package to validate upload integrity.
opts = {
  action: 'file_upload' # String | Defaults to `file_upload`, don't change it or request will fail!
}

begin
  #Upload a package
  result = api_instance.create(path, content, sha256_digest, opts)
  p result
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling PypiSimpleApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **path** | **String**|  | 
 **content** | **File**| A Python package release file to upload to the index. | 
 **sha256_digest** | **String**| SHA256 of package to validate upload integrity. | 
 **action** | **String**| Defaults to &#x60;file_upload&#x60;, don&#39;t change it or request will fail! | [optional] [default to &#39;file_upload&#39;]

### Return type

[**PackageUploadTaskResponse**](PackageUploadTaskResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## read

> read(path, opts)

Get index simple page

Gets the simple api html page for the index.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::PypiSimpleApi.new
path = 'path_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Get index simple page
  api_instance.read(path, opts)
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling PypiSimpleApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **path** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined


## read_0

> read_0(package, path, opts)

Get package simple page

Retrieves the simple api html page for a package.

### Example

```ruby
# load the gem
require 'pulp_python_client'
# setup authorization
PulpPythonClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpPythonClient::PypiSimpleApi.new
package = 'package_example' # String | 
path = 'path_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Get package simple page
  api_instance.read_0(package, path, opts)
rescue PulpPythonClient::ApiError => e
  puts "Exception when calling PypiSimpleApi->read_0: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **package** | **String**|  | 
 **path** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

nil (empty response body)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

